Documentation
¶
Overview ¶
* (c) 2016-2018 Adobe. All rights reserved. * This file is licensed to you under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. You may obtain a copy * of the License at http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or agreed to in writing, software distributed under * the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR REPRESENTATIONS * OF ANY KIND, either express or implied. See the License for the specific language * governing permissions and limitations under the License.
* (c) 2016-2018 Adobe. All rights reserved. * This file is licensed to you under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. You may obtain a copy * of the License at http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or agreed to in writing, software distributed under * the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR REPRESENTATIONS * OF ANY KIND, either express or implied. See the License for the specific language * governing permissions and limitations under the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InstanceProfile ¶
type InstanceProfile struct {
cfn.Resource
Properties struct {
Path string `json:"Path"`
Roles []Role `json:"Roles"`
} `json:"Properties"`
}
func NewInstanceProfile ¶
func NewInstanceProfile() InstanceProfile
type Policy ¶
type Role ¶
type Role struct {
cfn.Resource
Properties struct {
// AssumeRolePolicyDocument is arbitrary JSON
AssumeRolePolicyDocument map[string]interface{} `json:"AssumeRolePolicyDocument,omitempty"`
ManagedPolicyArns []string `json:"ManagedPolicyArns,omitempty"`
Path string `json:"Path,omitempty"`
Policies []Policy `json:"Policies,omitempty"`
} `json:"Properties"`
}
Source Files
¶
- instance_profile.go
- role.go